@@ -1,13 +1,14 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext, ugettext_lazy as _
 from django.conf import settings
 from django import forms
 from haystack.forms import ModelSearchForm, model_choices
+from cms_facetsearch.indexes import site
 
-overrides = {'cms.title': _('Page')}
+overrides = {'cms.title': _('Pages')}
 overrides.update(getattr(settings, 'CMS_FACETSEARCH_LABEL_OVERRIDES', {}))
 
-def override_model_choices(site=None):
-    choices = model_choices(site=site)
+def override_model_choices():
+    choices = model_choices()
     new_choices = []
     for k, v in choices:
         new_choices.append((k, overrides.get(k, v)))
@@ -20,7 +21,7 @@ class CmsFacetSearchModelForm(ModelSearchForm):
     def __init__(self, *args, **kwargs):
         self.selected_facets = kwargs.pop("selected_facets", [])
         super(CmsFacetSearchModelForm, self).__init__(*args, **kwargs)
-        self.fields['models'] = forms.MultipleChoiceField(choices=override_model_choices(), required=False, label=_('Search In'), 
+        self.fields['models'] = forms.MultipleChoiceField(choices=override_model_choices(), required=False, label=ugettext('Limit search to'), 
 widget=forms.CheckboxSelectMultiple)
 
     def search(self):
